@@ -1,7 +1,7 @@
 package Proc::Govern;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2016-04-07'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -129,8 +129,9 @@ too high and resumed if system load returns to a lower limit.
 _
         },
         load_check_every => {
-            schema => [int => default => 10],
-            summary => 'Frequency of load checking, in seconds',
+            schema => [duration => default => 10],
+            'x.perl.coerce_to' => 'int(secs)',
+            summary => 'Frequency of load checking',
         },
         load_high_limit => {
             schema => ['any*' => of => [[int => default => 1.25], 'code*']],
@@ -228,7 +229,7 @@ _
         },
         # not yet defined
         #restart_delay => {
-        #    schema => [int => default => 0],
+        #    schema => ['duration*', default=>0],
         #},
         #check_alive => {
         #    # not yet defined, can supply a custom coderef, or specify some
@@ -469,7 +470,7 @@ Proc::Govern - Run child process and govern its various aspects
 
 =head1 VERSION
 
-This document describes version 0.17 of Proc::Govern (from Perl distribution Proc-Govern), released on 2015-09-04.
+This document describes version 0.18 of Proc::Govern (from Perl distribution Proc-Govern), released on 2016-04-07.
 
 =head1 SYNOPSIS
 
@@ -561,6 +562,26 @@ Inspiration: djb's B<tcpserver>.
 
 =back
 
+=head1 EXIT CODES
+
+Below is the list of exit codes that Proc::Govern uses:
+
+=over
+
+=item * 124
+
+Timeout. The exit code is also used by B<timeout>.
+
+=item * 202
+
+Another instance is already running (when C<single_instance> option is true).
+
+=back
+
+=head1 CAVEATS
+
+Not yet tested on Win32.
+
 =head1 FUNCTIONS
 
 
@@ -573,6 +594,8 @@ lifetime of the child process.
 
 TODO: restart_delay, check_alive.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -592,9 +615,9 @@ load-generating processes are the subchildren of the one we're governing.
 
 This requires C<Proc::Killfam> CPAN module, which is installed separately.
 
-=item * B<load_check_every> => I<int> (default: 10)
+=item * B<load_check_every> => I<duration> (default: 10)
 
-Frequency of load checking, in seconds.
+Frequency of load checking.
 
 =item * B<load_high_limit> => I<int|code>
 
@@ -685,29 +708,6 @@ Return value: Child's exit code (int)
 
 =for Pod::Coverage ^(new)$
 
-=head1 EXIT CODES
-
-Below is the list of exit codes that Proc::Govern uses:
-
-=over
-
-=item * 124
-
-Timeout. The exit code is also used by B<timeout>.
-
-=item * 202
-
-Another instance is already running (when C<single_instance> option is true).
-
-=back
-
-=head1 ENVIRONMENT
-
-=head2 DEBUG => bool
-
-If set to true, will display debugging output to STDERR, e.g. when
-stopping/starting a process.
-
 =head1 FAQ
 
 =head2 Why use Proc::Govern?
@@ -728,9 +728,28 @@ which only creates one monitoring process, versus:
 which will create two parent processes (three actually, B<loadwatch> apparently
 forks first).
 
-=head1 CAVEATS
+=head1 ENVIRONMENT
 
-Not yet tested on Win32.
+=head2 DEBUG => bool
+
+If set to true, will display debugging output to STDERR, e.g. when
+stopping/starting a process.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Proc-Govern>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Proc-Govern>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Proc-Govern>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 SEE ALSO
 
@@ -781,29 +800,13 @@ Although not really related, L<Perinci::Sub::Wrapper>. This module also bundles
 functionalities like timeout, retries, argument validation, etc into a single
 function wrapper.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Proc-Govern>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Proc-Govern>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Proc-Govern>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
